@@ -1,13 +1,17 @@
-library(rcdk)
-
 up <- ping_service("cs_web")
 test_that("examples in the article are unchanged", {
   expect_false(is.inchikey("BQJCRHHNABKAKU-KBQPJGBKS-AN"))
-  expect_equal(capture_messages(is.inchikey("BQJCRHHNABKAKU-KBQPJGBKS-AN")),
+  # The default value for verbose has changed and it now requires verbose = TRUE
+  # to be added to the call to return the same output as the article example.
+  expect_equal(capture_messages(is.inchikey("BQJCRHHNABKAKU-KBQPJGBKS-AN",
+                                            verbose = TRUE)),
                "Hyphens not at position 15 and 26.\n")
   expect_false(is.cas('64-17-6'))
+  # The default value for verbose has changed and it now requires verbose = TRUE
+  # to be added to the call to return the same output as the article example.
   expect_equal(
-    capture_messages(is.cas("64-17-6")), "64-17-6: Checksum is not correct! 5 vs. 6\n")
+    capture_messages(is.cas("64-17-6", verbose = TRUE)),
+    "64-17-6: Checksum is not correct! 5 vs. 6\n")
   skip_if_not(up, "ChemSpider service is down, skipping tests")
   expect_false(is.inchikey("BQJCRHHNABKAKU-KBQPJGBKSA-5", type = "chemspider"))
 })
@@ -19,6 +23,8 @@ test_that("is.cas() returns correct results", {
   expect_false(is.cas('4-17-5'))
   expect_false(is.cas('64-177-6'))
   expect_false(is.cas('64-17-55'))
+  expect_false(is.cas(" 64-17-5"))
+  expect_false(is.cas("64-17-5 "))
 })
 
 test_that("as.cas() handles properly formatted CAS",{
@@ -61,7 +67,8 @@ test_that("is.inchikey() returns correct results", {
 
 test_that("is.smiles() returns correct results", {
   expect_true(is.smiles('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)Cl'))
-  expect_false(is.smiles('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)ClWWX'))
+  expect_false(suppressWarnings(
+    is.smiles('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)ClWWX')))
   expect_error(is.smiles(c('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)Cl',
                            'Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)Cl')))
 })
@@ -75,10 +82,48 @@ test_that("extr_num() returns correct results", {
 
 test_that("as.cas() returns correct reults", {
 
-  expect_equivalent(as.cas(58082), "58-08-2")
-  expect_equivalent(as.cas(123456789), NA)
-  expect_equivalent(as.cas(c(761659, 123456789, "hexenol")),
-                   c("761-65-9", NA, NA))
+  expect_equal(as.cas(58082), "58-08-2", ignore_attr = TRUE)
+  expect_equal(as.cas(123456789), NA,ignore_attr = TRUE)
+  expect_equal(as.cas(c(761659, 123456789, "hexenol")),
+                   c("761-65-9", NA, NA), ignore_attr = TRUE)
+})
+
+test_that("parse_mol()", {
+
+  vcr::use_cassette("parse_mol()",{
+    A <- cs_compinfo(2265, field = "Mol3D")
+    B <- cs_compinfo(2265, field = "Mol2D")
+    C <- cs_convert("BGEBZHIAGXMEMV-UHFFFAOYAX", "inchikey", "mol")
+  })
+
+  a <- parse_mol(A$mol3D)
+  b <- parse_mol(B$mol2D)
+  c <- parse_mol(C)
+
+  # issue #294
+  res <- POST("https://www.ebi.ac.uk/chembl/api/utils/smiles2ctab",
+              body = "CC(O)=O",
+              httr::user_agent(webchem:::webchem_url())
+  )
+  D <- rawToChar(res$content)
+  d <- parse_mol(D)
+
+  expect_type(a, "list")
+  expect_type(a$eh, "character")
+  expect_type(a$cl, "character")
+  expect_s3_class(a$ab, "data.frame")
+  expect_s3_class(a$bb, "data.frame")
+  expect_type(b, "list")
+  expect_type(c, "list")
+  expect_type(d, "list")
+})
+
+test_that("write_mol()", {
+  expect_error(write_mol(123), regex = "x is not a character string")
+  expect_error(write_mol("hello world"), regex = "x is not a Mol string")
+
+  # test a file output
+
 })
 
 test_that("matcher() warns when 'best' is used with chemical names", {
